@@ -130,9 +130,20 @@ class BaseDocument(object):
         '''
         self.objects.remove(instance=self, callback=callback, alias=alias)
 
-    def handle_load_reference(self, callback, references, reference_count, values_collection, field_name):
+    def fill_values_collection(self, collection, field_name, value):
+        collection[field_name] = value
+
+    def fill_list_values_collection(self, collection, field_name, value):
+        if not field_name in collection:
+            collection[field_name] = []
+        collection[field_name].append(value)
+
+    def handle_load_reference(self, callback, references, reference_count, values_collection, field_name, fill_values_method=None):
+        if fill_values_method is None:
+            fill_values_method = self.fill_values_collection
+
         def handle(*args, **kw):
-            values_collection[field_name] = args[0]
+            fill_values_method(values_collection, field_name, args[0])
 
             if reference_count > 0:
                 references.pop()
@@ -160,7 +171,7 @@ class BaseDocument(object):
             })
             return
 
-        for dereference_function, document_id, values_collection, field_name in references:
+        for dereference_function, document_id, values_collection, field_name, fill_values_method in references:
             dereference_function(
                 document_id,
                 callback=self.handle_load_reference(
@@ -168,7 +179,8 @@ class BaseDocument(object):
                     references=references,
                     reference_count=reference_count,
                     values_collection=values_collection,
-                    field_name=field_name
+                    field_name=field_name,
+                    fill_values_method=fill_values_method
                 )
             )
 
@@ -176,6 +188,9 @@ class BaseDocument(object):
         if results is None:
             results = []
 
+        if not isinstance(document, Document):
+            return results
+
         if fields:
             fields = [
                 (field_name, document._fields[field_name])
@@ -201,14 +216,29 @@ class BaseDocument(object):
                     field.reference_type.objects.get,
                     value,
                     document._values,
-                    field_name
+                    field_name,
+                    None
                 ])
 
     def find_list_field(self, document, results, field_name, field):
+        from motorengine.fields.reference_field import ReferenceField
         if self.is_list_field(field):
-            for value in document._values.get(field_name):
-                if value:
-                    self.find_references(document=value, results=results)
+            values = document._values.get(field_name)
+            if values:
+                document_type = values[0].__class__
+                if isinstance(field._base_field, ReferenceField):
+                    document_type = field._base_field.reference_type
+                    for value in values:
+                        results.append([
+                            document_type.objects.get,
+                            value,
+                            document._values,
+                            field_name,
+                            self.fill_list_values_collection
+                        ])
+                    document._values[field_name] = []
+                else:
+                    self.find_references(document=document_type, results=results)
 
     def find_embed_field(self, document, results, field_name, field):
         if self.is_embedded_field(field):
